package com.brilliance.isc.funds.crtcro.service;

import com.brilliance.isc.bo.Bch;
import com.brilliance.isc.bo.Pta;
import com.brilliance.isc.bo.model.Crdgrp;
import com.brilliance.isc.common.api.bch.service.BchService;
import com.brilliance.isc.common.cache.pta.PtaCacheService;
import com.brilliance.isc.common.cbsmod.service.CbsmodService;
import com.brilliance.isc.common.cbsmod.service.XrtmodService;
import com.brilliance.isc.common.contants.CommonContants;
import com.brilliance.isc.common.context.SettleContext;
import com.brilliance.isc.common.glemod.service.GlemodService;
import com.brilliance.isc.common.setmod.service.SetmodService;
import com.brilliance.isc.common.setmod.vo.SetmodVo;
import com.brilliance.isc.common.sysmod.SysmodService;
import com.brilliance.isc.common.transaction.AbstractTransactionService;
import com.brilliance.isc.common.transaction.help.TransactionHelpService;
import com.brilliance.isc.common.transaction.help.TransactionServiceSet;
import com.brilliance.isc.common.trnmod.service.TrnmodService;
import com.brilliance.isc.common.trnmod.vo.TrnmodVo;
import com.brilliance.isc.common.util.StringUtils;
import com.brilliance.isc.common.vo.BizAmdInfoVo;
import com.brilliance.isc.common.vo.BizInfoVo;
import com.brilliance.isc.common.vo.PtsptaVo;
import com.brilliance.isc.funds.bo.funds.CrtcroStoreBo;
import com.brilliance.isc.funds.common.component.CrToolComponent;
import com.brilliance.isc.funds.crtcro.check.CrtcroValidator;
import com.brilliance.isc.funds.vo.funds.CrtcroStoreVo;
import com.brilliance.isc.mda.dao.ActMapper;
import com.brilliance.isc.mda.dao.PtyratMapper;
import com.brilliance.isc.vo.funds.FxdBizInfoVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.util.Map;
import java.util.Objects;

import static com.brilliance.mda.runtime.mda.Constants.NULLSTR;

/**
 * @program: isc-funds
 * @ClassName: CrtcroTransactionServiceImpl
 * @description: 汇出清算 Crtcro 业务处理
 * @author: huangshunlin
 * @create: 2024-10-17 22:42
 */
@Service("crtcro.transaction")
public class CrtcroTransactionServiceImpl extends AbstractTransactionService<CrtcroStoreBo> {

    @Resource
    private CrtcroValidator crtcroValidator;

    @Resource
    private XrtmodService xrtmodService;

    @Resource
    private SysmodService sysmodService;

    @Resource
    private CrToolComponent crToolComponent;

    @Resource
    private TransactionHelpService transactionHelpService;

    @Resource
    private SettleContext settleContext;

    @Resource
    private CbsmodService cbsmodService;

    @Resource
    private TrnmodService trnmodService;

    @Resource
    private GlemodService glemodService;

    @Autowired
    private PtaCacheService ptaCacheService;

    @Resource
    private BchService bchService;

    @Resource
    private PtyratMapper ptyratMapper;

    @Resource
    private SetmodService setmodService;


    @Resource
    private ActMapper actMapper;

    @PostConstruct
    public void regisertService() {
        serviceRegisterMaps.put(CommonContants.SETMOD_SERVICE, "Y");
        serviceRegisterMaps.put(CommonContants.TRNDOC_SERVICE, "N");
        serviceRegisterMaps.put(CommonContants.GLEMOD_SERVICE, "Y");
        serviceRegisterMaps.put(CommonContants.TRNMOD_SERVICE, "Y");
        serviceRegisterMaps.put(CommonContants.BOPSET_JSH_SERVICE, "Y");
    }


    @Override
    protected void txnSave(CrtcroStoreBo transactionVo) {
        ruleMtabutSavN500(transactionVo);
    }

    public void ruleMtabutSavN500(CrtcroStoreBo bo) {

    }

    private void cbsSav(CrtcroStoreBo bo, TrnmodVo trnmodVo) {

    }

    @Override
    protected Map<String, String> txnCheck(CrtcroStoreBo transactionVo) {
        return crtcroValidator.validate(transactionVo);
    }

    @Override
    protected BizInfoVo buildBizInfo(CrtcroStoreBo transactionVo) {
        FxdBizInfoVo bizInfoVo = new FxdBizInfoVo();

        return bizInfoVo;
    }

    @Override
    protected BizAmdInfoVo buildBizAmdInfo(CrtcroStoreBo transactionVo) {
        return null;
    }

    @Override
    public CrtcroStoreBo init(CrtcroStoreBo crtcroStoreBo) {
        crtcroStoreBo.reset();
        init1000(crtcroStoreBo);
        return crtcroStoreBo;
    }

    /**
     * source:crtcro.0001.script
     */
    public void init1000(CrtcroStoreBo bo) {


    }

    private void init950(CrtcroStoreBo crtcroStoreBo) {
    }

    @Override
    public void beforeSave(CrtcroStoreBo transactionVo) {
        transactionVo.reset();
        transactionVo.reset();
        Crdgrp crdgrp = transactionVo.getCrdgrp();
        TransactionServiceSet transactionServiceSet = transactionHelpService.getTransactionStoreSet();
        transactionServiceSet.setRec(crdgrp.getRec());
        transactionServiceSet.setTransactionVo(transactionVo);
        crToolComponent.collectCbsMap(transactionServiceSet, "", crdgrp.getCbs(), "max");
        crToolComponent.collectPtsList(transactionServiceSet, crdgrp, null);
        settleContext.loadSettleSession(transactionVo.getTransName(), transactionVo.getUserId(), buildBizInfo(transactionVo), transactionServiceSet.getPtsList());

    }

    @Override
    protected void updateBizInfoVo(BizInfoVo bizInfoVo, CrtcroStoreBo transactionVo) {
        bizInfoVo.setObjinr(transactionVo.getCrdgrp().getRec().getInr());

    }

    public String getRef(CrtcroStoreVo crtcroStoreVo) {
        crtcroStoreVo.reset();
        PtsptaVo ptsptaVo = crtcroStoreVo.getCrdgrp().getApl();
        if (ptsptaVo == null || StringUtils.isEmpty(ptsptaVo.getPtainr())) {
            return NULLSTR;
        }
        Pta pta = ptaCacheService.getPtaByInr(ptsptaVo.getPtainr());
        Bch wrkbch = new Bch();
        wrkbch.setInr(pta.getBranchinr());
        wrkbch = bchService.selectByPrimaryKey(wrkbch);
        if (Objects.isNull(wrkbch)) {
            return NULLSTR;
        }
        SettleContext.getUserSession().setWrkbch(wrkbch);
        Crdgrp crdgrp = crtcroStoreVo.getCrdgrp();
        crToolComponent.getref(crdgrp);
        return crdgrp.getRec().getOwnref();
    }

    private SetmodVo buildSetmodVo(CrtcroStoreVo vo) {
        SetmodVo setmodVo = new SetmodVo();

        return setmodVo;
    }


}
