package com.brilliance.isc.funds.fxtsqo.service;

import com.brilliance.isc.bo.Bch;
import com.brilliance.isc.bo.Fxd;
import com.brilliance.isc.bo.model.Fxdgrp;
import com.brilliance.isc.common.api.bch.service.BchService;
import com.brilliance.isc.common.cache.pta.PtaCacheService;
import com.brilliance.isc.common.cbsmod.service.CbsmodService;
import com.brilliance.isc.common.cbsmod.service.XrtmodService;
import com.brilliance.isc.common.contants.CommonContants;
import com.brilliance.isc.common.context.SettleContext;
import com.brilliance.isc.common.glemod.service.GlemodService;
import com.brilliance.isc.common.setmod.service.SetmodService;
import com.brilliance.isc.common.sysmod.SysmodService;
import com.brilliance.isc.common.transaction.AbstractTransactionService;
import com.brilliance.isc.common.transaction.help.TransactionHelpService;
import com.brilliance.isc.common.transaction.help.TransactionServiceSet;
import com.brilliance.isc.common.trnmod.service.TrnmodService;
import com.brilliance.isc.common.trnmod.vo.TrnmodVo;
import com.brilliance.isc.common.util.I18nUtil;
import com.brilliance.isc.common.vo.BizAmdInfoVo;
import com.brilliance.isc.common.vo.BizInfoVo;
import com.brilliance.isc.funds.bo.funds.FxtsqoStoreBo;
import com.brilliance.isc.funds.common.component.FxToolComponent;
import com.brilliance.isc.funds.fxtlop.service.FxtpService;
import com.brilliance.isc.funds.fxtsqo.check.FxtsqoValidator;
import com.brilliance.isc.mda.dao.PtyratMapper;
import com.brilliance.isc.vo.funds.FxdBizInfoVo;
import com.brilliance.mda.runtime.mda.util.Dates;
import com.brilliance.mda.runtime.mda.util.MdaUtils;
import com.brilliance.mda.runtime.mda.util.Strings;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Map;

/**
 * @program: isc-funds
 * @ClassName: fxtsqoTransactionServiceImpl
 * @description: 即期售汇报价 fxtsqo 业务处理
 * @author: huangshunlin
 * @create: 2024-10-18 15:35
 */
@Service("fxtsqo.transaction")
public class FxtsqoTransactionServiceImpl extends AbstractTransactionService<FxtsqoStoreBo> {

    @Resource
    private FxtsqoValidator fxtsqoValidator;

    @Resource
    private XrtmodService xrtmodService;

    @Resource
    private SysmodService sysmodService;

    @Resource
    private FxToolComponent fxToolComponent;


    @Resource
    private TransactionHelpService transactionHelpService;


    @Resource
    private SettleContext settleContext;

    @Resource
    private CbsmodService cbsmodService;

    @Resource
    private TrnmodService trnmodService;

    @Resource
    private GlemodService glemodService;

    @Autowired
    private PtaCacheService ptaCacheService;

    @Resource
    private BchService bchService;

    @Resource
    private PtyratMapper ptyratMapper;

    @Resource
    private SetmodService setmodService;

    @Resource
    private FxtpService fxtpService;

    @PostConstruct
    public void regisertService() {
        serviceRegisterMaps.put(CommonContants.SETMOD_SERVICE, "Y");
        serviceRegisterMaps.put(CommonContants.TRNDIA_SERVICE, "Y");
        serviceRegisterMaps.put(CommonContants.GLEMOD_SERVICE, "Y");
        serviceRegisterMaps.put(CommonContants.TRNMOD_SERVICE, "Y");
    }


    @Override
    protected void txnSave(FxtsqoStoreBo transactionVo) {
        ruleMtabutSavN500(transactionVo);
    }

    /**
     * source:fxtsqo.0002.script
     */
    public void ruleMtabutSavN500(FxtsqoStoreBo bo) {
        TrnmodVo trnmodVo = transactionHelpService.getTransactionStoreSet().getTrnmodVo();
        fxToolComponent.getref(bo.getFxdgrp());
        // 1. Create (rsp. update) Contract (incl. Texts)
        fxToolComponent.sav(bo.getFxdgrp(), BigDecimal.ZERO);
        // 2. Build Transaction from FTDGRP
        trnmodService.trnSetFromContract(trnmodVo);
        cbsSav(bo);
        // save documents
    }

    /**
     * source:fxtsqo.0003.script
     */

    private void cbsSav(FxtsqoStoreBo bo) {
        String trninr = transactionHelpService.getTrninr();
        cbsmodService.cbsTrnSetNew("TRN", trninr);
        trnmodService.cbsTrnStore("NOMAMT", "AMT1", Dates.today(), bo.getFxdgrp().getCbs().getNom1().getCur(),
                bo.getFxdgrp().getCbs().getNom1().getAmt(), I18nUtil.getMessage("funds_fxtsqo_000000"), bo.getFxdgrp().getRec(), trninr);
        if (MdaUtils.compareTo(Strings.mid(bo.getFxdgrp().getRec().getFxtyp(), 1, 1), "S") == 0) {
            trnmodService.cbsTrnStore("UTLAMT", "AMT1", Dates.today(), bo.getFxdgrp().getCbs().getMax().getCur(),
                    bo.getFxdgrp().getCbs().getMax().getAmt(), I18nUtil.getMessage("funds_fxtsqo_000000"), bo.getFxdgrp().getRec(), trninr);
        }
    }

    @Override
    protected Map<String, String> txnCheck(FxtsqoStoreBo transactionVo) {
        return fxtsqoValidator.validate(transactionVo);
    }

    @Override
    protected BizInfoVo buildBizInfo(FxtsqoStoreBo transactionVo) {
        FxdBizInfoVo bizInfoVo = new FxdBizInfoVo();
        bizInfoVo.setObjtyp("FXD");
        Fxd rec = transactionVo.getFxdgrp().getRec();
        bizInfoVo.setObjinr(rec.getInr());
        bizInfoVo.setOwnref(rec.getOwnref());
        bizInfoVo.setFxtyp(rec.getFxtyp());
        bizInfoVo.setAcc(rec.getAcc());
        bizInfoVo.setAcc2(rec.getAcc2());
        bizInfoVo.setDsp(rec.getDsp());
        bizInfoVo.setDsp2(rec.getDsp2());
        bizInfoVo.setTrdint(rec.getTrdint());
        bizInfoVo.setTrdout(rec.getTrdout());
        bizInfoVo.setTrnman(rec.getTrnman());
        bizInfoVo.setRat(rec.getRat());
        bizInfoVo.setSetdat(rec.getSetdat());
        return bizInfoVo;
    }

    @Override
    protected BizAmdInfoVo buildBizAmdInfo(FxtsqoStoreBo transactionVo) {
        return null;
    }

    @Override
    public FxtsqoStoreBo init(FxtsqoStoreBo FxtsqoStoreBo) {
        FxtsqoStoreBo.reset();
        init1000(FxtsqoStoreBo);
        return FxtsqoStoreBo;
    }

    /**
     * source:fxtsqo.0001.script
     */
    public void init1000(FxtsqoStoreBo bo) {
        bo.getFxdgrp().getCbs().getNom1().setCur(xrtmodService.sysiso());

        Bch bch = bchService.getByBchInr(bo.getFxdgrp().getRec().getBchkeyinr());
        Bch wrkbch = bchService.getByBchInr(bo.getFxdgrp().getRec().getBranchinr());
        SettleContext.getUserSession().setBch(bch);
        SettleContext.getUserSession().setWrkbch(wrkbch);
//        ctx.getDaoSession().dbRead(this.getSysmod().getBch(),this.getFxdgrp().getRec().getBchkeyinr(),"INR");
//        ctx.getDaoSession().dbRead(this.getSysmod().getWrkbch(),this.getFxdgrp().getRec().getBranchinr(),"INR");
    }

    /**
     * source:fxtsqo.0000.script
     */
    private void init950(FxtsqoStoreBo bo) {
        //			this.getTrnmod().troLockExistingContract ( this.getFxdgrp());
        String inr = bo.getFxdgrp().getRec().getInr();
        Fxdgrp dbFxdgrp = fxToolComponent.getFxdgrpByInr(inr);
        bo.setFxdgrp(dbFxdgrp);

    }

    @Override
    public void beforeSave(FxtsqoStoreBo transactionVo) {
        transactionVo.reset();
        transactionVo.reset();
        Fxdgrp fxdgrp = transactionVo.getFxdgrp();
        TransactionServiceSet transactionServiceSet = transactionHelpService.getTransactionStoreSet();
        transactionServiceSet.setRec(fxdgrp.getRec());
        transactionServiceSet.setBlk(fxdgrp.getBlk());
        transactionServiceSet.setTransactionVo(transactionVo);
        fxToolComponent.collectCbsMap(transactionServiceSet, "", fxdgrp.getCbs(), "max", "nom1", "opn1", "opn2");
        fxToolComponent.collectPtsList(transactionServiceSet, fxdgrp, null);
        settleContext.loadSettleSession(transactionVo.getTransName(), transactionVo.getUserId(), buildBizInfo(transactionVo), transactionServiceSet.getPtsList());

    }

    @Override
    protected void updateBizInfoVo(BizInfoVo bizInfoVo, FxtsqoStoreBo transactionVo) {
        bizInfoVo.setObjinr(transactionVo.getFxdgrp().getRec().getInr());

    }

}
