package com.brilliance.isc.funds.fxtssb.resource;

import com.brilliance.isc.common.context.SettleContext;
import com.brilliance.isc.common.transaction.controller.AbstractTransactionController;
import com.brilliance.isc.funds.fxtssb.service.FxtssbTransactionServiceImpl;
import com.brilliance.isc.funds.transfer.transaction.FxtssbStructMapper;
import com.brilliance.isc.funds.vo.funds.FxtssbStoreVo;
import com.brilliance.isc.transfer.IStructMapper;
import com.brilliance.isc.vo.ResponseSet;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @program: isc-funds
 * @ClassName: FxtssbResource
 * @description: 即期结汇 Fxtssb 请求入口
 * @author: huangshunlin
 * @create: 2024-10-08 15:34
 */
@RestController
@RequestMapping("/fxtssb")
@Api("即期结汇")
public class FxtssbResource extends AbstractTransactionController<FxtssbStoreVo> {

    @Resource
    private FxtssbStructMapper fxtssbStructMapper;

    public IStructMapper getStructMapper() {
        return fxtssbStructMapper;
    }


    @Resource(name = "fxtssb.transaction")
    FxtssbTransactionServiceImpl fxtssbTransactionService;

    @Autowired
    private SettleContext settleContext;

    /**
     * 根据结售汇类型 等获取业务参号
     *
     * @param fxtssbStoreVo
     * @return
     */
    @PostMapping("/getRef")
    public ResponseSet<String> getRef(@RequestBody FxtssbStoreVo fxtssbStoreVo) {
        String ref = fxtssbTransactionService.getRef(fxtssbStoreVo);
        return ResponseSet.simpleSuccess(ref);
    }

    @PostMapping("/defaultAccountsN1000")
    public ResponseSet defaultAccountsN1000(@RequestBody FxtssbStoreVo fxtssbStoreVo) {
        try {
            settleContext.loadSettleSession("FXTSSB","","");
            Map<String, List<String>> codeSet = fxtssbTransactionService.defaultAccountsN1000(fxtssbStoreVo);
            ResponseSet success = ResponseSet.simpleSuccess(fxtssbStoreVo);
            success.setCodeSet(codeSet);
            return success;
        } catch (Exception e) {
            throw e;
        } finally {
            SettleContext.removeUserSession();
        }
    }

    @PostMapping("/defaultRateN1000")
    public ResponseSet defaultRateN1000(@RequestBody FxtssbStoreVo fxtssbStoreVo) {
        try {
            settleContext.loadSettleSession("FXTSSB","","");
            fxtssbTransactionService.defaultRateN1000(fxtssbStoreVo);
            return ResponseSet.simpleSuccess(fxtssbStoreVo);
        } catch (Exception e) {
            throw e;
        } finally {
            SettleContext.removeUserSession();
        }

    }

    @PostMapping("/defaultCalculateN1100")
    public ResponseSet defaultCalculateN1100(@RequestBody FxtssbStoreVo fxtssbStoreVo) {
        try {
            settleContext.loadSettleSession("FXTSSB","","");
            fxtssbTransactionService.defaultCalculateN1100(fxtssbStoreVo);
            return ResponseSet.simpleSuccess(fxtssbStoreVo);
        } catch (Exception e) {
            throw e;
        } finally {
            SettleContext.removeUserSession();
        }

    }

}
