package com.brilliance.isc.funds.transfer.transaction;

import com.brilliance.isc.funds.bo.funds.FxtssbStoreBo;
import com.brilliance.isc.funds.vo.funds.FxtssbStoreVo;
import com.brilliance.isc.transfer.IBaseStructMapper;
import org.mapstruct.Mapper;
import org.mapstruct.MappingTarget;
import org.mapstruct.factory.Mappers;

/**
 * @program: isc-funds
 * @ClassName: FxtssbStructMapper
 * @description: 即期结汇转换Fxtssb Bo、Vo之间的转换处理类。如果有很复杂的函数，则可以用适配器模式重写
 * @author: huangshunlin
 * @create: 2024-10-08 15:27
 */
@Mapper(componentModel = "spring")
public interface FxtssbStructMapper extends IBaseStructMapper<FxtssbStoreBo, FxtssbStoreVo> {
    /**
     * 此行语句一定要写，StructMapper需要
     */
    FxtssbStructMapper INSTANCE = Mappers.getMapper(FxtssbStructMapper.class);

    /**
     * Vo转为Bo
     *
     * @param vo
     * @return 返回业务Bo
     */
    @Override
    FxtssbStoreBo voTransferToBo(FxtssbStoreVo vo);

    /**
     * Vo追加更新至Bo
     *
     * @param vo
     * @param bo
     */
    @Override
    void voUpdateToBo(FxtssbStoreVo vo, @MappingTarget FxtssbStoreBo bo);

    /**
     * Bo转为Vo
     *
     * @param bo
     * @return 返回Vo
     */
    @Override
    FxtssbStoreVo boTransferToVo(FxtssbStoreBo bo);

    /**
     * bo追加更新至Bo
     *
     * @param bo
     * @param vo
     */
    @Override
    void boUpdateToVo(FxtssbStoreBo bo, @MappingTarget FxtssbStoreVo vo);
}

