package com.brilliance.isc.funds.vo.funds;

import com.brilliance.isc.bo.Act;
import com.brilliance.isc.bo.Gle;
import com.brilliance.isc.bo.Smh;
import com.brilliance.isc.bo.Trn;
import com.brilliance.isc.bo.model.Crdgrp;
import com.brilliance.isc.bo.model.Crtmod;
import com.brilliance.isc.common.transaction.vo.BaseTransactionVo;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import lombok.Data;

import java.math.BigDecimal;
import java.util.Date;

import static com.brilliance.mda.runtime.mda.Constants.NULLSTR;

/**
 * @program: isc-funds
 * @ClassName: CrtcriStoreVo
 * @description: 汇出清算 bo
 * @author: huangshunlin
 * @create: 2024-10-17 22:33
 */
@Data
@JsonIgnoreProperties(ignoreUnknown = true)
public class CrtcroStoreVo extends BaseTransactionVo {

    //Direct payment one message (max=1)
    private String dirindflg = NULLSTR;
    //Which MT to beneficiary institution  (max=3)
    private String sftmt = NULLSTR;
    //Message Init Flag (max=1)
    private String msgflg = NULLSTR;
    //21 TAG for MTs  (max=16)
    private String tag21 = NULLSTR;
    //Amount   (scale=3)
    private BigDecimal amt32 = new BigDecimal("0.00");
    //Amount  (scale=3)
    private BigDecimal amt33 = new BigDecimal("0.00");
    //Currency (max=3)
    private String cur32 = NULLSTR;
    //Currency  (max=3)
    private String cur33 = NULLSTR;
    //valdat in tag 32

    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date dat32;
    //valdat in tag 33

    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date dat33;
    //swift tag 71B  (max=35)
    private String tag71b = NULLSTR;
    //II_BIC in MTs  (max=12)
    private String ownbic = NULLSTR;
    //Tag 999 (max=65)
    private String tag999 = NULLSTR;
    //Status I-INCOMING, O-OUTGOING, N-NOTNEED  (max=1)
    private String clrsta = NULLSTR;

    private Crdgrp crdgrp;

    private Crtmod crtmod;

    private Trn cretrn;

    private Smh cresmh;

    private Smh bndsmh;

    private Gle spcgle;

    private Act pacact;

    @Override
    public void reset() {
        super.reset();
        if (crdgrp == null) {
            crdgrp = new Crdgrp();
        }
        crdgrp.reset();

        if (crtmod == null) {
            crtmod = new Crtmod();
        }
        crtmod.reset();

        if (cretrn == null) {
            cretrn = new Trn();
        }

        if (cresmh == null) {
            cresmh = new Smh();
        }

        if (bndsmh == null) {
            bndsmh = new Smh();
        }
        if (spcgle == null) {
            spcgle = new Gle();
        }
        if (pacact == null) {
            pacact = new Act();
        }
    }
}
